==> testdisk_6.4.1.orig.tar.gz: testdisk-6.4.1/src/file_pst.c <==
/*

    File: file_pst.c

    Copyright (C) 2006 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 59
    Temple Place - Suite 330, Boston MA 02111-1307, USA.

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include "types.h"
#include "photorec.h"

static const char* header_check_pst(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);

const t_file_hint file_hint_pst= {
  .extension="pst",
  .description="Outlook",
  .min_header_distance=0,
  .min_filesize=16,
  .max_filesize=PHOTOREC_MAX_FILE_SIZE,
  .recover=1,
  .header_check=&header_check_pst,
  .data_check=NULL,
  .file_check=NULL
};

static const char* header_check_pst(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
{
  const unsigned char pst_header[4]= { '!','B','D','N'};
  const unsigned char dbx_header[4]= { 0xCF, 0xAD, 0x12, 0xFE };
  const unsigned char wab_header[16] = { 0x9c, 0xcb, 0xcb, 0x8d, 0x13, 0x75, 0xd2, 0x11,
    0x91, 0x58, 0x00, 0xc0, 0x4f, 0x79, 0x56, 0xa4 };
  if(memcmp(buffer,wab_header,sizeof(wab_header))==0)
    return "wab";	/* Adresse Book */
  if(memcmp(buffer,dbx_header,sizeof(dbx_header))==0)
    return "dbx";
  if(memcmp(buffer,pst_header,sizeof(pst_header))==0)
    return file_hint_pst.extension;
  return NULL;
}

==> testdisk_6.5.orig.tar.gz: testdisk-6.5.orig/src/file_pst.c <==
/*

    File: file_pst.c

    Copyright (C) 2006 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include <stdio.h>
#include "types.h"
#include "photorec.h"

static const char* header_check_pst(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);

const t_file_hint file_hint_pst= {
  .extension="pst",
  .description="Outlook",
  .min_header_distance=0,
  .min_filesize=16,
  .max_filesize=PHOTOREC_MAX_FILE_SIZE,
  .recover=1,
  .header_check=&header_check_pst,
  .data_check=NULL,
  .file_check=NULL
};

static const char* header_check_pst(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
{
  const unsigned char pst_header[4]= { '!','B','D','N'};
  const unsigned char dbx_header[4]= { 0xCF, 0xAD, 0x12, 0xFE };
  const unsigned char wab_header[16] = { 0x9c, 0xcb, 0xcb, 0x8d, 0x13, 0x75, 0xd2, 0x11,
    0x91, 0x58, 0x00, 0xc0, 0x4f, 0x79, 0x56, 0xa4 };
  if(memcmp(buffer,wab_header,sizeof(wab_header))==0)
    return "wab";	/* Adresse Book */
  if(memcmp(buffer,dbx_header,sizeof(dbx_header))==0)
    return "dbx";
  if(memcmp(buffer,pst_header,sizeof(pst_header))==0)
    return file_hint_pst.extension;
  return NULL;
}
